Skip to main content Crate syscall_map Copy item path Source DynamicSyscallMap Runtime-mutable syscall map that owns its data
This allows for dynamic updates at runtime SyscallMap Static syscall map using lifetimes for compile-time and borrowed data
Supports both static (compile-time) and dynamic (runtime) syscall lists via lifetimes compute_syscall_entries Runtime helper for dynamic syscall lists
Computes hashes and sorts entries, borrowing from the input compute_syscall_entries_const Helper function for compile-time syscall map creation
Computes hashes and sorts entries at compile time murmur3_32 MurmurHash3 32-bit hash function (const-compatible)